## do not run the following code unless the library adapt is loaded ##
## fit the Gaussian process ##
x1 = kronecker(seq(0,1,by=.25), rep(1,5))
x2 = rep(seq(0,1,by=.25),5)
z = 4 * x1 - 2*x2 + x1 * x2 + rnorm(length(x1))
fit = mlegp(cbind(x1,x2), z, param.names = c("x1", "x2"))
## calculate the proportion of total variance accounted for by x1 ##
ANOVAMainEffect(fit, "x1") / FunctionalVariance(fit) * 100
## check this against 'FANOVADecomposition' ##
FANOVADecomposition(fit)Run the code above in your browser using DataLab