Learn R Programming

mlegp (version 2.2.6)

FANOVADecomposition: Sensitivity Analysis for Gaussian Processes and Gaussian Process Lists

Description

Performs Functional Analysis of Variance (FANOVA) decomposition on a Gaussian process or (a subset of) all Gaussian processes in a Gaussian process list

Usage

FANOVADecomposition(gp, Interaction = TRUE, verbose = TRUE, outputs = NULL, maxpts = NULL, 
	lower = NULL, upper = NULL)

Arguments

gp
an object of class gp or gp.list
Interaction
if TRUE (the default), calculates two-way factor interactions
verbose
if TRUE (the default), prints status updates
outputs
if gp is of class gp.list, a vector of integers specifying the Gaussian processes to analyze; all Gaussian processes in the list are analyzed by default
maxpts
the maximum number of function evaluations used in the calculation of each predicted output, see adapt
lower
a vector of minimum values of ALL parameters of the gp design matrix, defaulting to the minimum value of each parameter in the design
upper
a vector of maximum values of ALL parameters of the gp design matrix, defaulting to the maximum value of each parameter in the design

Value

  • a data.frame where the first column contains the names of the effects, and elements in row i and column j correspond to the percentage of the total functional variance of Gaussian process (j-1) accounted for by effect i

Details

Implements the FANOVA decomposition of Schonlau and Welch (2006), for main and two-way factor effects, using a prior distribution of all components that is ~ independent U(a,b), where (a,b) corresponds to the (min,max) value of that component in the design. For all parameters, (a,b) can be overwritten via the arguments lower and upper.

The functions integrate and adapt from the library adapt are used for one dimensional and multidimensional integration, respectively.

References

Schonlau, M. and Welch, W. 2006. Screening the Input Variables to a Computer Model Via Analysis of Variance and Visualization, in Screening: Methods for Experimentation in Industry, Drug Discovery, and Genetics. A Dean and S. Lewis, eds. (New York: Springer).

http://users.nsula.edu/dancikg/mlegp/

See Also

FANOVAFunctions; nice for rounding entries in the FANOVA table; plotMainEffects and plotInteractionEffect for plotting main and 2-way interaction effects; integrate and package adapt for details on single and multi-dimensional integration

Examples

Run this code
## Do not run the following code unless the library adapt is loaded ##

## fit the Gaussian process ##
x1 = kronecker(seq(0,1,by=.25), rep(1,5))
x2 = rep(seq(0,1,by=.25),5)
z = 4 * x1 - 2*x2 + x1 * x2 + rnorm(length(x1), sd = 0.001)
fit = mlegp(cbind(x1,x2), z, param.names = c("x1", "x2"))

## Find percent contribution of all effects ##
FANOVADecomposition(fit)

## Round contributions to 3 digits ##
nice(FANOVADecomposition(fit), 3) ### end don't run

Run the code above in your browser using DataLab