Learn R Programming

mlegp (version 2.2.6)

createGP: creates a Gaussian process object

Description

creates a Gaussian process gp object

Usage

createGP(X, Z, beta, a, meanReg, sig2, nugget, param.names = 1:dim(X)[2], constantMean = 1)

Arguments

X
the design matrix
Z
output obtained from the design matrix X, as a vector or a 1-column matrix
beta
vector of correlation coefficients
a
vector of smoothness parameters in the correlation function (if mlegp is used, these will be 2)
meanReg
the constant mean if constantMean = 1, otherwise the regression coefficients of the mean function such that meanReg pre-multiplied by (1 X) will produce the mean matrix
sig2
the unconditional variance of the Gaussian process
nugget
the constant nugget or a vector of length nrow(X) corresponding to the diagonal nugget matrix
param.names
optional vector of parameter names (with length equal to ncol(X)
constantMean
1 if the Gaussian process has a constant mean; 0 otherwise

Value

  • an object of class gp that contains the following components:
  • Zmatrix of observations
  • numObsnumber of observations
  • Xthe design matrix
  • numDimnumber of dimensions of X
  • constantMean1 if GP has a constant mean; 0 otherwise
  • muthe mean matrix
  • Bhatmean function regression coefficients
  • betacorrelation parameters
  • asmoothness parameters in correlation function
  • sig2unconditional variance of predicted expected output
  • paramsvector of parameter names, corresponding to columns of X
  • invVarMatrixinverse var-cov matrix
  • nuggetconstant nugget or vector corresponding to the diagonal nugget matrix
  • loglikethe log likelihood of the observations
  • cvresults from cross-validation, where cv[,1] are the cross-validated predictions cv[,2] are the variances of the cross-validated predictions

References

http://users.nsula.edu/dancikg/mlegp/

See Also

mlegp