Learn R Programming

mlegp (version 2.2.6)

gp.list: Gaussian Process Lists

Description

Creates an object of type gp.list, given a list of Gaussian processes fit to separate sets of observations, or a list of Gaussian processes fit to principle component weights to approximate output of high dimension

Usage

gp.list(..., param.names = NULL, UD = NULL, gp.names = NULL)

Arguments

...
either a list object, where each element is a Gaussian process; or several objects of type gp
param.names
optionally, the parameter names corresponding to the columns of the design matrix of all Gaussian processes. By default, this will be equal to the parameter names of the first Gaussian process in ...
UD
the UD matrix, if the Gaussian process is fit to principle component weights
gp.names
optionally, a vector of names for the Gaussian processes, defaulting to gp #1, gp #2, ...

Value

  • A gp.list object is a list object, where the first k elements correspond to k Gaussian processes passed in as .... This makes it straightforward to access a single Gaussian process. In addition, gp.list contains components:
  • paramsa vector of parameter names, corresponding to the columns of the design matrix
  • numGPsthe number of Gaussian processes in the list
  • numDimthe number of parameters in the design matrix
  • numObsthe number of observations
  • namesthe names of the Gaussian processes

References

http://users.nsula.edu/dancikg/mlegp/

See Also

mlegp, mlegp-svd-functions for more details about the UD matrix

Examples

Run this code
x = -5:5
  y1 = sin(x) + rnorm(length(x), sd=.1)
  y2 = sin(x) + rnorm(length(x), sd = .5)

  ## create the gp.list object ## 
  fitMulti = mlegp(x, cbind(y1,y2))

  plot(fitMulti)
 
  fitMulti   ## print summary of of the fitted Gaussian process list
  fitMulti[[2]]  ## print summary for the 2nd Gaussian process

Run the code above in your browser using DataLab