Learn R Programming

mlegp (version 2.2.6)

mlegp-nugget-related: Gaussian Process Nugget Related Functions

Description

Functions for detecting replicates and for calculating sample variance at specific design points

Usage

varPerReps(X, Y)
estimateNugget(X, Y)
anyReps(X)

Arguments

X
the design matrix
Y
a vector (or 1 column matrix) of observations

Value

  • varPerReps returns a 1-column matrix where element i corresponds to the sample variance in observations corresponding to design point X[i]

    estimateNugget returns a double calculated by taking the mean of the matrix returned by varPerReps

    anyReps returns TRUE if two or more rows of X are identical

References

http://users.nsula.edu/dancikg/mlegp/

Examples

Run this code
x = matrix(c(1,1,2,3,3))   # the design matrix
y = matrix(c(5,6,7,0,10))  # output

anyReps(x)
varPerReps(x,y)
estimateNugget(x,y)

Run the code above in your browser using DataLab