Usage
createGP(X, Z, beta, a, meanReg, sig2, nugget, param.names = 1:dim(X)[2], constantMean = 1)
Arguments
Z
output obtained from the design matrix X, as a vector or a 1-column matrix
beta
vector of correlation coefficients
a
vector of smoothness parameters in the correlation function (if mlegp is used, these will be 2)
meanReg
the constant mean if constantMean = 1, otherwise the regression coefficients of the mean function such that meanReg pre-multiplied by (1 X) will produce the mean matrix
sig2
the unconditional variance of the Gaussian process
nugget
the constant nugget or a vector of length nrow(X) corresponding to the diagonal nugget matrix
param.names
optional vector of parameter names (with length equal to ncol(X)
constantMean
1 if the Gaussian process has a constant mean; 0 otherwise