powered by
varPerReps(X, Y) estimateNugget(X, Y) anyReps(X)
varPerReps
estimateNugget returns a double calculated by taking the mean of the matrix returned by varPerReps
estimateNugget
anyReps returns TRUE if two or more rows of X are identical
anyReps
TRUE
X
x = matrix(c(1,1,2,3,3)) # the design matrix y = matrix(c(5,6,7,0,10)) # output anyReps(x) varPerReps(x,y) estimateNugget(x,y)
Run the code above in your browser using DataLab