Rdocumentation
powered by
Learn R Programming
mlegp (version 2.2.6)
nice: FANOVA formatting functions
Description
Prints out FANOVA decomposition tables in a 'nice' format by rounding entries to the specified number of decimal places
Usage
nice(x, digits = 4)
Arguments
x
an FANOVA decomposition table, obtained from
FANOVADecomposition
digits
integer indicating the precision to be used
Value
A
nice
version of the object
x
Details
Rounds elements in all columns of
x
, except for the first column, to the specified number of decimal places indicated by
precision
References
http://users.nsula.edu/dancikg/mlegp/
See Also
FANOVADecomposition
for an example